<p align="center">
  <b>Fast & scalable MCMC for all your exoplanet needs!</b>
  <br><br>
  <a href="https://rodluger.github.io/starry"><img src="https://img.shields.io/badge/powered_by-starry-EB5368.svg?style=flat"/></a>
  <a href="https://celerite.readthedocs.io"><img src="https://img.shields.io/badge/powered_by-celerite-EB5368.svg?style=flat"/></a>
  <a href="https://docs.pymc.io"><img src="https://img.shields.io/badge/powered_by-pymc3-EB5368.svg?style=flat"/></a>
</p>
